@@ -18,11 +18,11 @@
   };
   displayError = function displayError(j, status, err) {
     var res;
-    console.log('Error', err);
+    console.error('Error', err);
     res = JSON.parse(j.responseText);
     if (res && res.error) {
       res = res.error.replace(/.* /, '');
-      console.log('Returned error', res);
+      console.error('Returned error', res);
       return setMsg(res, 'warning');
     }
   };
